| AnsariBradley | R Documentation |
Performs Ansari-Bradley test on samples.
LearnNonparam::PermuTest -> LearnNonparam::TwoSampleTest -> AnsariBradley
new()Create a new AnsariBradley object.
AnsariBradley$new(
type = c("permu", "asymp"),
alternative = c("two_sided", "less", "greater"),
n_permu = 10000
)typea character string specifying the way to calculate the p-value.
alternativea character string specifying the alternative hypothesis.
n_permuan integer indicating number of permutations for the permutation distribution. If set to 0, all permutations will be used.
A AnsariBradley object.
pmt(
"twosample.ansari",
alternative = "greater", n_permu = 0
)$test(Table2.8.1)$print()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.