| CDF | R Documentation |
Performs statistical inference on population cumulative distribution function.
LearnNonparam::PermuTest -> LearnNonparam::OneSampleTest -> CDF
new()Create a new CDF object.
CDF$new(method = c("binomial", "dkw"), conf_level = 0.95)methoda character string specifying whether to use a confidence band based on the binomial distribution or the Dvoretzky–Kiefer–Wolfowitz inequality.
conf_levela number specifying confidence level of the confidence bounds.
A CDF object.
plot()Plot the estimate and confidence bounds for population cumulative distribution function.
CDF$plot(style = c("graphics", "ggplot2"))stylea character string specifying which package to use.
The object itself (invisibly).
pmt("onesample.cdf")$test(Table1.2.1)$plot(style = "graphic")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.