| ChiSquare | R Documentation |
Performs chi-square test on contingency tables.
LearnNonparam::PermuTest -> LearnNonparam::ContingencyTableTest -> ChiSquare
new()Create a new ChiSquare object.
ChiSquare$new(type = c("permu", "asymp"), n_permu = 10000)typea character string specifying the way to calculate the p-value.
n_permuan integer indicating number of permutations for the permutation distribution. If set to 0, all permutations will be used.
A ChiSquare object.
t <- pmt(
"table.chisq", n_permu = 0
)$test(Table5.4.2)$print()
t$type <- "asymp"
t
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.