| Correlation | R Documentation |
Performs correlation coefficient based two-sample association test on samples.
LearnNonparam::PermuTest -> LearnNonparam::TwoSampleTest -> LearnNonparam::TwoSamplePairedTest -> LearnNonparam::TwoSampleAssociationTest -> Correlation
new()Create a new Correlation object.
Correlation$new(
type = c("permu", "asymp"),
method = c("pearson", "kendall", "spearman"),
alternative = c("two_sided", "less", "greater"),
n_permu = 10000
)typea character string specifying the way to calculate the p-value.
methoda character string specifying the correlation coefficient to be used.
alternativea character string specifying the alternative hypothesis.
n_permuan integer indicating number of permutations for the permutation distribution. If set to 0, all permutations will be used.
A Correlation object.
pmt(
"association.corr", method = "pearson",
alternative = "greater", n_permu = 10000
)$test(Table5.1.2)$print()
t <- pmt(
"association.corr", method = "spearman",
alternative = "two_sided", n_permu = 10000
)$test(Table5.1.2)$print()
t$type <- "asymp"
t
t <- pmt(
"association.corr", method = "kendall",
alternative = "greater", n_permu = 0
)$test(Table5.2.2)$print()
t$type <- "asymp"
t
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.