| Difference | R Documentation |
Performs mean/median based two-sample test on samples.
LearnNonparam::PermuTest -> LearnNonparam::TwoSampleTest -> LearnNonparam::TwoSampleLocationTest -> Difference
new()Create a new Difference object.
Difference$new(
method = c("mean", "median"),
alternative = c("two_sided", "less", "greater"),
null_value = 0,
n_permu = 10000
)methoda character string specifying whether to use the mean or the median.
alternativea character string specifying the alternative hypothesis.
null_valuea number indicating the true value of the location shift.
n_permuan integer indicating number of permutations for the permutation distribution. If set to 0, all permutations will be used.
A Difference object.
pmt(
"twosample.difference", method = "mean",
alternative = "greater", n_permu = 0
)$test(Table2.1.1)$print()$plot(
style = "graphic", breaks = seq(-20, 25, length.out = 9)
)
pmt(
"twosample.difference", method = "mean",
alternative = "greater", n_permu = 1000
)$test(Table2.3.1)$print()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.