| JonckheereTerpstra | R Documentation |
Performs Jonckheere-Terpstra test on samples.
LearnNonparam::PermuTest -> LearnNonparam::KSampleTest -> JonckheereTerpstra
new()Create a new JonckheereTerpstra object.
JonckheereTerpstra$new(
type = c("permu", "asymp"),
alternative = c("two_sided", "less", "greater"),
n_permu = 10000
)typea character string specifying the way to calculate the p-value.
alternativea character string specifying the alternative hypothesis.
n_permuan integer indicating number of permutations for the permutation distribution. If set to 0, all permutations will be used.
A JonckheereTerpstra object.
t <- pmt(
"ksample.jt", alternative = "greater"
)$test(Table3.4.1)$print()
t$type <- "asymp"
t
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.