| KruskalWallis | R Documentation |
Performs Kruskal-Wallis test on samples.
LearnNonparam::PermuTest -> LearnNonparam::KSampleTest -> KruskalWallis
new()Create a new KruskalWallis object.
KruskalWallis$new(
type = c("permu", "asymp"),
scoring = c("rank", "vw", "expon"),
n_permu = 10000
)typea character string specifying the way to calculate the p-value.
scoringa character string specifying the scoring system.
n_permuan integer indicating number of permutations for the permutation distribution. If set to 0, all permutations will be used.
A KruskalWallis object.
pmt(
"ksample.kw", type = "asymp"
)$test(Table3.2.2)$print()
t <- pmt(
"ksample.kw", type = "permu"
)$test(Table3.2.3)$print()
t$type <- "asymp"
t
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.