| OneWay | R Documentation |
Performs F statistic based one-way test on samples.
LearnNonparam::PermuTest -> LearnNonparam::KSampleTest -> OneWay
new()Create a new OneWay object.
OneWay$new(type = c("permu", "asymp"), n_permu = 10000)typea character string specifying the way to calculate the p-value.
n_permuan integer indicating number of permutations for the permutation distribution. If set to 0, all permutations will be used.
A OneWay object.
t <- pmt(
"ksample.oneway", n_permu = 0
)$test(Table3.1.2)$print()
t$type <- "asymp"
t
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.