| Page | R Documentation |
Performs Page test on samples collected in a randomized complete block design.
LearnNonparam::PermuTest -> LearnNonparam::RCBDTest -> Page
new()Create a new Page object.
Page$new(
type = c("permu", "asymp"),
alternative = c("two_sided", "less", "greater"),
n_permu = 10000
)typea character string specifying the way to calculate the p-value.
alternativea character string specifying the alternative hypothesis.
n_permuan integer indicating number of permutations for the permutation distribution. If set to 0, all permutations will be used.
A Page object.
t <- pmt(
"rcbd.page", alternative = "less"
)$test(Table4.4.3)$print()
t$type <- "asymp"
t
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.