| PairedDifference | R Documentation |
Performs differences based paired comparison on samples.
LearnNonparam::PermuTest -> LearnNonparam::TwoSampleTest -> LearnNonparam::TwoSamplePairedTest -> PairedDifference
correctWhether to apply continuity correction when scoring is set to "rank".
new()Create a new PairedDifference object.
PairedDifference$new(
type = c("permu", "asymp"),
method = c("with_zeros", "without_zeros"),
scoring = c("none", "rank", "vw", "expon"),
alternative = c("two_sided", "less", "greater"),
null_value = 0,
n_permu = 10000,
correct = TRUE
)typea character string specifying the way to calculate the p-value.
methoda character string specifying the method of ranking data in computing adjusted signed scores for tied data, must be one of "with_zeros" (default) or "without_zeros".
scoringa character string specifying the scoring system.
alternativea character string specifying the alternative hypothesis.
null_valuea number indicating the true value of the location shift.
n_permuan integer indicating number of permutations for the permutation distribution. If set to 0, all permutations will be used.
correcta logical indicating whether to apply continuity correction in the normal approximation for the p-value when scoring is set to "rank".
A PairedDifference object.
pmt(
"paired.difference",
alternative = "greater", scoring = "none", n_permu = 0
)$test(Table4.1.1)$print()
pmt(
"paired.difference", n_permu = 0
)$test(Table4.1.3)$print()
t <- pmt(
"paired.difference", scoring = "rank",
alternative = "greater", n_permu = 0
)$test(Table4.1.1)$print()
t$type <- "asymp"
t
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.