| Quantile | R Documentation |
Performs quantile test on a single sample. In addition, an estimation and a confidence interval for the desired quantile will be calculated.
LearnNonparam::PermuTest -> LearnNonparam::OneSampleTest -> Quantile
probThe probability associated with the quantile.
correctWhether to apply continuity correction.
new()Create a new Quantile object.
Quantile$new(
type = c("asymp", "exact"),
alternative = c("two_sided", "less", "greater"),
null_value = 0,
conf_level = 0.95,
prob = 0.5,
correct = TRUE
)typea character string specifying the way to calculate the p-value.
alternativea character string specifying the alternative hypothesis.
null_valuea number indicating the hypothesized value of the quantile.
conf_levela number between zero and one indicating the confidence level to use.
proba number between zero and one indicating the probability associated with the quantile.
correcta logical indicating whether to apply continuity correction in the normal approximation for the p-value.
A Quantile object.
pmt(
"onesample.quantile", prob = 0.5,
null_value = 75, alternative = "greater",
type = "asymp", correct = FALSE
)$test(Table1.1.1)$print()
pmt(
"onesample.quantile",
prob = 0.25, conf_level = 0.90
)$test(Table1.2.1)$conf_int
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.