| RCBDOneWay | R Documentation |
Performs F statistic based one-way test on samples collected in a randomized complete block design.
LearnNonparam::PermuTest -> LearnNonparam::RCBDTest -> RCBDOneWay
new()Create a new RCBDOneWay object.
RCBDOneWay$new(type = c("permu", "asymp"), n_permu = 10000)typea character string specifying the way to calculate the p-value.
n_permuan integer indicating number of permutations for the permutation distribution. If set to 0, all permutations will be used.
A RCBDOneWay object.
t <- pmt(
"rcbd.oneway", n_permu = 5000
)$test(Table4.4.3)$print()
t$type <- "asymp"
t
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.