| ScoreSum | R Documentation |
Performs sum of scores based two-sample test on samples. It is almost the same as two-sample wilcoxon rank sum test but uses more scoring systems.
LearnNonparam::PermuTest -> LearnNonparam::TwoSampleTest -> LearnNonparam::TwoSampleLocationTest -> ScoreSum
new()Create a new ScoreSum object.
ScoreSum$new(
scoring = c("rank", "vw", "expon"),
alternative = c("two_sided", "less", "greater"),
null_value = 0,
n_permu = 10000
)scoringa character string specifying the scoring system.
alternativea character string specifying the alternative hypothesis.
null_valuea number indicating the true value of the location shift.
n_permuan integer indicating number of permutations for the permutation distribution. If set to 0, all permutations will be used.
A ScoreSum object.
pmt(
"twosample.scoresum", scoring = "expon",
alternative = "greater", n_permu = 0
)$test(Table2.6.2)$print()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.