| SiegelTukey | R Documentation |
Performs Siegel-Tukey test on samples.
LearnNonparam::PermuTest -> LearnNonparam::TwoSampleTest -> LearnNonparam::TwoSampleLocationTest -> LearnNonparam::Wilcoxon -> SiegelTukey
new()Create a new SiegelTukey object.
SiegelTukey$new(
type = c("permu", "asymp"),
alternative = c("two_sided", "less", "greater"),
n_permu = 10000,
correct = TRUE
)typea character string specifying the way to calculate the p-value.
alternativea character string specifying the alternative hypothesis.
n_permuan integer indicating number of permutations for the permutation distribution. If set to 0, all permutations will be used.
correcta logical indicating whether to apply continuity correction in the normal approximation for the p-value.
A SiegelTukey object.
pmt(
"twosample.siegel",
alternative = "greater", n_permu = 0
)$test(Table2.8.1)$print()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.