| Sign | R Documentation |
Performs two-sample sign test on samples.
LearnNonparam::PermuTest -> LearnNonparam::TwoSampleTest -> LearnNonparam::TwoSamplePairedTest -> Sign
correctWhether to apply continuity correction.
new()Create a new Sign object.
Sign$new(
type = c("permu", "asymp"),
alternative = c("two_sided", "less", "greater"),
n_permu = 10000,
correct = TRUE
)typea character string specifying the way to calculate the p-value.
alternativea character string specifying the alternative hypothesis.
n_permuan integer indicating number of permutations for the permutation distribution. If set to 0, all permutations will be used.
correcta logical indicating whether to apply continuity correction in the normal approximation for the p-value.
A Sign object.
t <- pmt(
"paired.sign",
alternative = "greater", n_permu = 0
)$test(
rep(c(+1, -1), c(12, 5)), rep(0, 17)
)$print()
t$type <- "asymp"
t
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.