| Studentized | R Documentation |
Performs studentized statistic based multiple comparison on samples.
LearnNonparam::PermuTest -> LearnNonparam::KSampleTest -> LearnNonparam::MultipleComparison -> Studentized
new()Create a new Studentized object.
Studentized$new(
type = c("permu", "asymp"),
method = c("bonferroni", "tukey"),
scoring = c("none", "rank", "vw", "expon"),
conf_level = 0.95,
n_permu = 10000
)typea character string specifying the way to calculate the p-value.
methoda character string specifying whether to use Bonferroni's method or Tukey's HSD method.
scoringa character string specifying the scoring system.
conf_levela number between zero and one indicating the family-wise confidence level to use.
n_permuan integer indicating number of permutations for the permutation distribution. If set to 0, all permutations will be used.
A Studentized object.
t <- pmt(
"multcomp.studentized", method = "bonferroni"
)$test(Table3.3.1)$print()
t$type <- "asymp"
t
t$scoring <- "rank"
t
t$method <- "tukey"
t
t$scoring <- "none"
t
t$type <- "permu"
t
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.