| Table2.8.1 | R Documentation |
The amounts of liquid in randomly selected beverage containers before and after the filling process has been repaired.
Table2.8.1
An object of class data.frame with 5 rows and 2 columns.
Table 2.8.1
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.