| Table3.2.3 | R Documentation |
Saltiness scores, on a scale of 1 to 5, assigned by a taste expert to samples of 3 food products that differ in the amounts of soymeal they contain.
Table3.2.3
An object of class list of length 3.
Table 3.2.3
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.