Table4.4.3: Yield Data

Table4.4.3R Documentation

Yield Data

Description

Yield data for a randomized complete block design in which 4 different types of tractors were used in tilling the soil. The blocking factor is location of the fields.

Usage

Table4.4.3

Format

An object of class data.frame with 4 rows and 6 columns.

Table 4.4.3


LearnNonparam documentation built on June 8, 2025, 1:46 p.m.