| Wilcoxon | R Documentation |
Performs two-sample wilcoxon test on samples. In addition, an estimation and a confidence interval for the location shift will be calculated.
LearnNonparam::PermuTest -> LearnNonparam::TwoSampleTest -> LearnNonparam::TwoSampleLocationTest -> Wilcoxon
correctWhether to apply continuity correction.
new()Create a new Wilcoxon object.
Wilcoxon$new(
type = c("permu", "asymp"),
alternative = c("two_sided", "less", "greater"),
null_value = 0,
conf_level = 0.95,
n_permu = 10000,
correct = TRUE
)typea character string specifying the way to calculate the p-value.
alternativea character string specifying the alternative hypothesis.
null_valuea number indicating the true value of the location shift.
conf_levela number between zero and one indicating the confidence level to use.
n_permuan integer indicating number of permutations for the permutation distribution. If set to 0, all permutations will be used.
correcta logical indicating whether to apply continuity correction in the normal approximation for the p-value.
A Wilcoxon object.
pmt(
"twosample.wilcoxon",
alternative = "greater", n_permu = 0
)$test(Table2.1.1)$print()
pmt(
"twosample.wilcoxon",
alternative = "less", n_permu = 0
)$test(Table2.6.1)$print()
pmt(
"twosample.wilcoxon", conf_level = 0.90
)$test(Table2.6.2)$conf_int
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.