| Table4.4.3 | R Documentation |
Yield data for a randomized complete block design in which 4 different types of tractors were used in tilling the soil. The blocking factor is location of the fields.
Table4.4.3
An object of class data.frame with 4 rows and 6 columns.
Table 4.4.3
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.